@@ -6,6 +6,7 @@ CLI_CONFIG = {
     "acct_key": {"subcommands": ["encrypt", "decrypt"]},
     "acct_file": {"subcommands": ["encrypt", "decrypt"]},
     "extras": {},
+    "overrides": {},
     "render_pipe": {},
     "crypto_plugin": {"subcommands": ["encrypt", "decrypt"]},
     "output": {"source": "rend", "subcommands": ["decrypt"]},
@@ -27,6 +28,11 @@ CONFIG = {
         "default": {},
         "help": "Additional arbitrary configuration values as a json string",
     },
+    "overrides": {
+        "render": "json",
+        "default": {},
+        "help": "Non-secure profile data that will override the values in the encrypted acct file",
+    },
     "crypto_plugin": {
         "default": "fernet",
         "help": "The crypto plugin to use with acct",
