@@ -71,17 +71,17 @@ async def decrypt_file(
     """
     Read a file and decrypt and deserialize the data
     """
-    async with aiofiles.open(acct_file, "rb") as fh_:
-        raw = await fh_.read()
-
     if acct_key:
+        async with aiofiles.open(acct_file, "rb") as fh_:
+            raw = await fh_.read()
         # Use the acct key to decrypt the data, it was already rendered when it was encrypted
         return await hub.crypto.init.decrypt(
             plugin=crypto_plugin, data=raw, key=acct_key
         )
     else:
+        hub.log.warning("No acct_key provided, rendering plaintext acct_file")
         # If no acct key was provided then pass the raw data to the render pipes
-        return await hub.rend.init.parse_bytes(raw, pipe=render_pipe)
+        return await hub.rend.init.parse(acct_file, pipe=render_pipe)
 
 
 def dump(hub, data: Dict) -> bytes:
